<h1 align="center">salamenc</h1>
<p align="center">It's a beautiful project that helps developers program To Decrypt Python Files. </p>

![](https://img.shields.io/badge/SALAM-HUNTER-orange?style=for-the-badge&logo=python.svg) 
<p align="center">
<a href="#"><img title="Made in KURDISH" src="https://img.shields.io/badge/MADE%20IN-KURDISH-red.svg?style=for-the-badge&logo=github"></a>

</p>
<p align="center">
<img alt="salammzere3' Github Stats" src="https://github-readme-stats.vercel.app/api?username=salammzere3&show_icons=true&include_all_commits=true&hide_border=true" />

</p>
<p align="center">
<a href="#"><img title="telegram Num" src="https://img.shields.io/badge/telegram%20Num-Salam Hunter-red.svg?style=for-the-badge&logo=telegram"></a>
</p>
<p align="center">
<a href="https://github.com/salammzere3/followers"><img title="Followers" src="https://img.shields.io/github/followers/salammzere3?color=blue&style=flat-square"></a>
</p>

## Installation :
```
pip install salamenc 
```
### How to Use

``` To Import
from salamenc import * 
``` To Encrypt 
crypt.encode("print('Hi')")
``` To Run
crypt.run('Encrypt')
```

## Follow us on social media
[![Github](https://img.shields.io/badge/Github-salammzere3-orange?style=for-the-badge&logo=github)](https://github.com/salammzere3/)
[![Telegram](https://img.shields.io/badge/Telegram-@T5B55-orange?style=for-the-badge&logo=Telegram)](https://t.me/T5B55)